@@ -52,4 +52,4 @@ class JobServices(IDracManager,
                                      do_async=do_async,
                                      do_expanded=do_expanded)
 
-        return CommandResult(cmd_result, None, None)
+        return CommandResult(cmd_result, None, None, None)
